Welcome to Aliases's documentation!
===================================

version |version|

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   getting_started
   reference/toc

..
   Indices and tables
   ==================

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
..